==> mobiusft-1.3.zip: mobiusft-1.3/src/mobius/crypt/cipher_block_mode_impl_ecb.h <==
#ifndef __MOBIUS_CRYPT_CIPHER_BLOCK_MODE_IMPL_ECB_H__
#define __MOBIUS_CRYPT_CIPHER_BLOCK_MODE_IMPL_ECB_H__

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/crypt/cipher_block_mode_impl_base.h>

namespace mobius
{
namespace crypt
{
class cipher_block;

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief Electronic Codebook (ecb) block cipher mode implementation class
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class cipher_block_mode_impl_ecb : public cipher_block_mode_impl_base
{
public:
  // function prototypes
  void encrypt (mobius::bytearray&) override;
  void decrypt (mobius::bytearray&) override;
  void reset () noexcept override;
};

} // namespace crypt
} // namespace mobius

#endif

==> mobiusft-1.8.zip: mobiusft-1.8/src/mobius/crypt/cipher_block_mode_impl_ecb.h <==
#ifndef MOBIUS_CRYPT_CIPHER_BLOCK_MODE_IMPL_ECB_H
#define MOBIUS_CRYPT_CIPHER_BLOCK_MODE_IMPL_ECB_H

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
// Mobius Forensic Toolkit
// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018 Eduardo Aguiar
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
// Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
#include <mobius/crypt/cipher_block_mode_impl_base.h>

namespace mobius
{
namespace crypt
{
class cipher_block;

// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
//! \brief Electronic Codebook (ecb) block cipher mode implementation class
// =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class cipher_block_mode_impl_ecb : public cipher_block_mode_impl_base
{
public:
  explicit cipher_block_mode_impl_ecb (cipher_block&);
  void encrypt (mobius::bytearray&) override;
  void decrypt (mobius::bytearray&) override;
  void reset () noexcept override;

private:
  cipher_block& cipher_;
};

} // namespace crypt
} // namespace mobius

#endif
